/*
 * This file is generated by gdbus-codegen, do not modify it.
 *
 * The license of this code is the same as for the D-Bus interface description
 * it was derived from. Note that it links to GLib, so must comply with the
 * LGPL linking clauses.
 */

#ifdef HAVE_CONFIG_H
#  include "config.h"
#endif

#include "gdbus-test-codegen-generated-interface-info.h"

#include <string.h>

/* ------------------------------------------------------------------------ */
/* Definitions for org.project.Bar */

const GDBusAnnotationInfo * const org_project_bar_interface__hello_world_method_in_args__greeting_arg_annotations[] =
{
  NULL,
};

const GDBusArgInfo org_project_bar_interface__hello_world_method_in_args__greeting_arg =
{
  -1,  /* ref count */
  (gchar *) "greeting",
  (gchar *) "s",
  (GDBusAnnotationInfo **) org_project_bar_interface__hello_world_method_in_args__greeting_arg_annotations,
};

const GDBusArgInfo * const org_project_bar_interface__hello_world_method_in_args[] =
{
  &org_project_bar_interface__hello_world_method_in_args__greeting_arg,
  NULL,
};

const GDBusAnnotationInfo * const org_project_bar_interface__hello_world_method_out_args__response_arg_annotations[] =
{
  NULL,
};

const GDBusArgInfo org_project_bar_interface__hello_world_method_out_args__response_arg =
{
  -1,  /* ref count */
  (gchar *) "response",
  (gchar *) "s",
  (GDBusAnnotationInfo **) org_project_bar_interface__hello_world_method_out_args__response_arg_annotations,
};

const GDBusArgInfo * const org_project_bar_interface__hello_world_method_out_args[] =
{
  &org_project_bar_interface__hello_world_method_out_args__response_arg,
  NULL,
};

const GDBusAnnotationInfo org_project_bar_interface__hello_world_method_annotations__key3_annotation =
{
  -1,  /* ref count */
  (gchar *) "Key3",
  (gchar *) "Value3",
  NULL,  /* no annotations */
};

const GDBusAnnotationInfo org_project_bar_interface__hello_world_method_annotations__existing_annotation_annotation =
{
  -1,  /* ref count */
  (gchar *) "ExistingAnnotation",
  (gchar *) "blah",
  NULL,  /* no annotations */
};

const GDBusAnnotationInfo * const org_project_bar_interface__hello_world_method_annotations[] =
{
  &org_project_bar_interface__hello_world_method_annotations__key3_annotation,
  &org_project_bar_interface__hello_world_method_annotations__existing_annotation_annotation,
  NULL,
};

const GDBusMethodInfo org_project_bar_interface__hello_world_method =
{
  -1,  /* ref count */
  (gchar *) "HelloWorld",
  (GDBusArgInfo **) org_project_bar_interface__hello_world_method_in_args,
  (GDBusArgInfo **) org_project_bar_interface__hello_world_method_out_args,
  (GDBusAnnotationInfo **) org_project_bar_interface__hello_world_method_annotations,
};

const GDBusArgInfo org_project_bar_interface__test_primitive_types_method_in_args__val_byte_arg =
{
  -1,  /* ref count */
  (gchar *) "val_byte",
  (gchar *) "y",
  NULL,  /* no annotations */
};

const GDBusArgInfo org_project_bar_interface__test_primitive_types_method_in_args__val_boolean_arg =
{
  -1,  /* ref count */
  (gchar *) "val_boolean",
  (gchar *) "b",
  NULL,  /* no annotations */
};

const GDBusArgInfo org_project_bar_interface__test_primitive_types_method_in_args__val_int16_arg =
{
  -1,  /* ref count */
  (gchar *) "val_int16",
  (gchar *) "n",
  NULL,  /* no annotations */
};

const GDBusArgInfo org_project_bar_interface__test_primitive_types_method_in_args__val_uint16_arg =
{
  -1,  /* ref count */
  (gchar *) "val_uint16",
  (gchar *) "q",
  NULL,  /* no annotations */
};

const GDBusAnnotationInfo org_project_bar_interface__test_primitive_types_method_in_args__val_int32_arg_annotations__key6_annotation =
{
  -1,  /* ref count */
  (gchar *) "Key6",
  (gchar *) "Value6",
  NULL,  /* no annotations */
};

const GDBusAnnotationInfo * const org_project_bar_interface__test_primitive_types_method_in_args__val_int32_arg_annotations[] =
{
  &org_project_bar_interface__test_primitive_types_method_in_args__val_int32_arg_annotations__key6_annotation,
  NULL,
};

const GDBusArgInfo org_project_bar_interface__test_primitive_types_method_in_args__val_int32_arg =
{
  -1,  /* ref count */
  (gchar *) "val_int32",
  (gchar *) "i",
  (GDBusAnnotationInfo **) org_project_bar_interface__test_primitive_types_method_in_args__val_int32_arg_annotations,
};

const GDBusArgInfo org_project_bar_interface__test_primitive_types_method_in_args__val_uint32_arg =
{
  -1,  /* ref count */
  (gchar *) "val_uint32",
  (gchar *) "u",
  NULL,  /* no annotations */
};

const GDBusArgInfo org_project_bar_interface__test_primitive_types_method_in_args__val_int64_arg =
{
  -1,  /* ref count */
  (gchar *) "val_int64",
  (gchar *) "x",
  NULL,  /* no annotations */
};

const GDBusArgInfo org_project_bar_interface__test_primitive_types_method_in_args__val_uint64_arg =
{
  -1,  /* ref count */
  (gchar *) "val_uint64",
  (gchar *) "t",
  NULL,  /* no annotations */
};

const GDBusArgInfo org_project_bar_interface__test_primitive_types_method_in_args__val_double_arg =
{
  -1,  /* ref count */
  (gchar *) "val_double",
  (gchar *) "d",
  NULL,  /* no annotations */
};

const GDBusArgInfo org_project_bar_interface__test_primitive_types_method_in_args__val_string_arg =
{
  -1,  /* ref count */
  (gchar *) "val_string",
  (gchar *) "s",
  NULL,  /* no annotations */
};

const GDBusArgInfo org_project_bar_interface__test_primitive_types_method_in_args__val_objpath_arg =
{
  -1,  /* ref count */
  (gchar *) "val_objpath",
  (gchar *) "o",
  NULL,  /* no annotations */
};

const GDBusArgInfo org_project_bar_interface__test_primitive_types_method_in_args__val_signature_arg =
{
  -1,  /* ref count */
  (gchar *) "val_signature",
  (gchar *) "g",
  NULL,  /* no annotations */
};

const GDBusArgInfo org_project_bar_interface__test_primitive_types_method_in_args__val_bytestring_arg =
{
  -1,  /* ref count */
  (gchar *) "val_bytestring",
  (gchar *) "ay",
  NULL,  /* no annotations */
};

const GDBusArgInfo * const org_project_bar_interface__test_primitive_types_method_in_args[] =
{
  &org_project_bar_interface__test_primitive_types_method_in_args__val_byte_arg,
  &org_project_bar_interface__test_primitive_types_method_in_args__val_boolean_arg,
  &org_project_bar_interface__test_primitive_types_method_in_args__val_int16_arg,
  &org_project_bar_interface__test_primitive_types_method_in_args__val_uint16_arg,
  &org_project_bar_interface__test_primitive_types_method_in_args__val_int32_arg,
  &org_project_bar_interface__test_primitive_types_method_in_args__val_uint32_arg,
  &org_project_bar_interface__test_primitive_types_method_in_args__val_int64_arg,
  &org_project_bar_interface__test_primitive_types_method_in_args__val_uint64_arg,
  &org_project_bar_interface__test_primitive_types_method_in_args__val_double_arg,
  &org_project_bar_interface__test_primitive_types_method_in_args__val_string_arg,
  &org_project_bar_interface__test_primitive_types_method_in_args__val_objpath_arg,
  &org_project_bar_interface__test_primitive_types_method_in_args__val_signature_arg,
  &org_project_bar_interface__test_primitive_types_method_in_args__val_bytestring_arg,
  NULL,
};

const GDBusArgInfo org_project_bar_interface__test_primitive_types_method_out_args__ret_byte_arg =
{
  -1,  /* ref count */
  (gchar *) "ret_byte",
  (gchar *) "y",
  NULL,  /* no annotations */
};

const GDBusArgInfo org_project_bar_interface__test_primitive_types_method_out_args__ret_boolean_arg =
{
  -1,  /* ref count */
  (gchar *) "ret_boolean",
  (gchar *) "b",
  NULL,  /* no annotations */
};

const GDBusArgInfo org_project_bar_interface__test_primitive_types_method_out_args__ret_int16_arg =
{
  -1,  /* ref count */
  (gchar *) "ret_int16",
  (gchar *) "n",
  NULL,  /* no annotations */
};

const GDBusArgInfo org_project_bar_interface__test_primitive_types_method_out_args__ret_uint16_arg =
{
  -1,  /* ref count */
  (gchar *) "ret_uint16",
  (gchar *) "q",
  NULL,  /* no annotations */
};

const GDBusArgInfo org_project_bar_interface__test_primitive_types_method_out_args__ret_int32_arg =
{
  -1,  /* ref count */
  (gchar *) "ret_int32",
  (gchar *) "i",
  NULL,  /* no annotations */
};

const GDBusAnnotationInfo org_project_bar_interface__test_primitive_types_method_out_args__ret_uint32_arg_annotations__key7_annotation =
{
  -1,  /* ref count */
  (gchar *) "Key7",
  (gchar *) "Value7",
  NULL,  /* no annotations */
};

const GDBusAnnotationInfo * const org_project_bar_interface__test_primitive_types_method_out_args__ret_uint32_arg_annotations[] =
{
  &org_project_bar_interface__test_primitive_types_method_out_args__ret_uint32_arg_annotations__key7_annotation,
  NULL,
};

const GDBusArgInfo org_project_bar_interface__test_primitive_types_method_out_args__ret_uint32_arg =
{
  -1,  /* ref count */
  (gchar *) "ret_uint32",
  (gchar *) "u",
  (GDBusAnnotationInfo **) org_project_bar_interface__test_primitive_types_method_out_args__ret_uint32_arg_annotations,
};

const GDBusArgInfo org_project_bar_interface__test_primitive_types_method_out_args__ret_int64_arg =
{
  -1,  /* ref count */
  (gchar *) "ret_int64",
  (gchar *) "x",
  NULL,  /* no annotations */
};

const GDBusArgInfo org_project_bar_interface__test_primitive_types_method_out_args__ret_uint64_arg =
{
  -1,  /* ref count */
  (gchar *) "ret_uint64",
  (gchar *) "t",
  NULL,  /* no annotations */
};

const GDBusArgInfo org_project_bar_interface__test_primitive_types_method_out_args__ret_double_arg =
{
  -1,  /* ref count */
  (gchar *) "ret_double",
  (gchar *) "d",
  NULL,  /* no annotations */
};

const GDBusArgInfo org_project_bar_interface__test_primitive_types_method_out_args__ret_string_arg =
{
  -1,  /* ref count */
  (gchar *) "ret_string",
  (gchar *) "s",
  NULL,  /* no annotations */
};

const GDBusArgInfo org_project_bar_interface__test_primitive_types_method_out_args__ret_objpath_arg =
{
  -1,  /* ref count */
  (gchar *) "ret_objpath",
  (gchar *) "o",
  NULL,  /* no annotations */
};

const GDBusArgInfo org_project_bar_interface__test_primitive_types_method_out_args__ret_signature_arg =
{
  -1,  /* ref count */
  (gchar *) "ret_signature",
  (gchar *) "g",
  NULL,  /* no annotations */
};

const GDBusArgInfo org_project_bar_interface__test_primitive_types_method_out_args__ret_bytestring_arg =
{
  -1,  /* ref count */
  (gchar *) "ret_bytestring",
  (gchar *) "ay",
  NULL,  /* no annotations */
};

const GDBusArgInfo * const org_project_bar_interface__test_primitive_types_method_out_args[] =
{
  &org_project_bar_interface__test_primitive_types_method_out_args__ret_byte_arg,
  &org_project_bar_interface__test_primitive_types_method_out_args__ret_boolean_arg,
  &org_project_bar_interface__test_primitive_types_method_out_args__ret_int16_arg,
  &org_project_bar_interface__test_primitive_types_method_out_args__ret_uint16_arg,
  &org_project_bar_interface__test_primitive_types_method_out_args__ret_int32_arg,
  &org_project_bar_interface__test_primitive_types_method_out_args__ret_uint32_arg,
  &org_project_bar_interface__test_primitive_types_method_out_args__ret_int64_arg,
  &org_project_bar_interface__test_primitive_types_method_out_args__ret_uint64_arg,
  &org_project_bar_interface__test_primitive_types_method_out_args__ret_double_arg,
  &org_project_bar_interface__test_primitive_types_method_out_args__ret_string_arg,
  &org_project_bar_interface__test_primitive_types_method_out_args__ret_objpath_arg,
  &org_project_bar_interface__test_primitive_types_method_out_args__ret_signature_arg,
  &org_project_bar_interface__test_primitive_types_method_out_args__ret_bytestring_arg,
  NULL,
};

const GDBusMethodInfo org_project_bar_interface__test_primitive_types_method =
{
  -1,  /* ref count */
  (gchar *) "TestPrimitiveTypes",
  (GDBusArgInfo **) org_project_bar_interface__test_primitive_types_method_in_args,
  (GDBusArgInfo **) org_project_bar_interface__test_primitive_types_method_out_args,
  NULL,  /* no annotations */
};

const GDBusArgInfo org_project_bar_interface__test_non_primitive_types_method_in_args__dict_s_to_s_arg =
{
  -1,  /* ref count */
  (gchar *) "dict_s_to_s",
  (gchar *) "a{ss}",
  NULL,  /* no annotations */
};

const GDBusArgInfo org_project_bar_interface__test_non_primitive_types_method_in_args__dict_s_to_pairs_arg =
{
  -1,  /* ref count */
  (gchar *) "dict_s_to_pairs",
  (gchar *) "a{s(ii)}",
  NULL,  /* no annotations */
};

const GDBusArgInfo org_project_bar_interface__test_non_primitive_types_method_in_args__a_struct_arg =
{
  -1,  /* ref count */
  (gchar *) "a_struct",
  (gchar *) "(iss)",
  NULL,  /* no annotations */
};

const GDBusArgInfo org_project_bar_interface__test_non_primitive_types_method_in_args__array_of_strings_arg =
{
  -1,  /* ref count */
  (gchar *) "array_of_strings",
  (gchar *) "as",
  NULL,  /* no annotations */
};

const GDBusArgInfo org_project_bar_interface__test_non_primitive_types_method_in_args__array_of_objpaths_arg =
{
  -1,  /* ref count */
  (gchar *) "array_of_objpaths",
  (gchar *) "ao",
  NULL,  /* no annotations */
};

const GDBusArgInfo org_project_bar_interface__test_non_primitive_types_method_in_args__array_of_signatures_arg =
{
  -1,  /* ref count */
  (gchar *) "array_of_signatures",
  (gchar *) "ag",
  NULL,  /* no annotations */
};

const GDBusArgInfo org_project_bar_interface__test_non_primitive_types_method_in_args__array_of_bytestrings_arg =
{
  -1,  /* ref count */
  (gchar *) "array_of_bytestrings",
  (gchar *) "aay",
  NULL,  /* no annotations */
};

const GDBusArgInfo * const org_project_bar_interface__test_non_primitive_types_method_in_args[] =
{
  &org_project_bar_interface__test_non_primitive_types_method_in_args__dict_s_to_s_arg,
  &org_project_bar_interface__test_non_primitive_types_method_in_args__dict_s_to_pairs_arg,
  &org_project_bar_interface__test_non_primitive_types_method_in_args__a_struct_arg,
  &org_project_bar_interface__test_non_primitive_types_method_in_args__array_of_strings_arg,
  &org_project_bar_interface__test_non_primitive_types_method_in_args__array_of_objpaths_arg,
  &org_project_bar_interface__test_non_primitive_types_method_in_args__array_of_signatures_arg,
  &org_project_bar_interface__test_non_primitive_types_method_in_args__array_of_bytestrings_arg,
  NULL,
};

const GDBusArgInfo org_project_bar_interface__test_non_primitive_types_method_out_args__ret_array_of_strings_arg =
{
  -1,  /* ref count */
  (gchar *) "ret_array_of_strings",
  (gchar *) "as",
  NULL,  /* no annotations */
};

const GDBusArgInfo org_project_bar_interface__test_non_primitive_types_method_out_args__ret_array_of_objpaths_arg =
{
  -1,  /* ref count */
  (gchar *) "ret_array_of_objpaths",
  (gchar *) "ao",
  NULL,  /* no annotations */
};

const GDBusArgInfo org_project_bar_interface__test_non_primitive_types_method_out_args__ret_array_of_signatures_arg =
{
  -1,  /* ref count */
  (gchar *) "ret_array_of_signatures",
  (gchar *) "ag",
  NULL,  /* no annotations */
};

const GDBusArgInfo org_project_bar_interface__test_non_primitive_types_method_out_args__ret_array_of_bytestrings_arg =
{
  -1,  /* ref count */
  (gchar *) "ret_array_of_bytestrings",
  (gchar *) "aay",
  NULL,  /* no annotations */
};

const GDBusArgInfo org_project_bar_interface__test_non_primitive_types_method_out_args__result_arg =
{
  -1,  /* ref count */
  (gchar *) "result",
  (gchar *) "ay",
  NULL,  /* no annotations */
};

const GDBusArgInfo * const org_project_bar_interface__test_non_primitive_types_method_out_args[] =
{
  &org_project_bar_interface__test_non_primitive_types_method_out_args__ret_array_of_strings_arg,
  &org_project_bar_interface__test_non_primitive_types_method_out_args__ret_array_of_objpaths_arg,
  &org_project_bar_interface__test_non_primitive_types_method_out_args__ret_array_of_signatures_arg,
  &org_project_bar_interface__test_non_primitive_types_method_out_args__ret_array_of_bytestrings_arg,
  &org_project_bar_interface__test_non_primitive_types_method_out_args__result_arg,
  NULL,
};

const GDBusMethodInfo org_project_bar_interface__test_non_primitive_types_method =
{
  -1,  /* ref count */
  (gchar *) "TestNonPrimitiveTypes",
  (GDBusArgInfo **) org_project_bar_interface__test_non_primitive_types_method_in_args,
  (GDBusArgInfo **) org_project_bar_interface__test_non_primitive_types_method_out_args,
  NULL,  /* no annotations */
};

const GDBusArgInfo org_project_bar_interface__request_signal_emission_method_in_args__which_one_arg =
{
  -1,  /* ref count */
  (gchar *) "which_one",
  (gchar *) "i",
  NULL,  /* no annotations */
};

const GDBusArgInfo * const org_project_bar_interface__request_signal_emission_method_in_args[] =
{
  &org_project_bar_interface__request_signal_emission_method_in_args__which_one_arg,
  NULL,
};

const GDBusMethodInfo org_project_bar_interface__request_signal_emission_method =
{
  -1,  /* ref count */
  (gchar *) "RequestSignalEmission",
  (GDBusArgInfo **) org_project_bar_interface__request_signal_emission_method_in_args,
  NULL,  /* no out args */
  NULL,  /* no annotations */
};

const GDBusMethodInfo org_project_bar_interface__request_multi_property_mods_method =
{
  -1,  /* ref count */
  (gchar *) "RequestMultiPropertyMods",
  NULL,  /* no in args */
  NULL,  /* no out args */
  NULL,  /* no annotations */
};

const GDBusMethodInfo org_project_bar_interface__unimplemented_method_method =
{
  -1,  /* ref count */
  (gchar *) "UnimplementedMethod",
  NULL,  /* no in args */
  NULL,  /* no out args */
  NULL,  /* no annotations */
};

const GDBusMethodInfo org_project_bar_interface__property_cancellation_method =
{
  -1,  /* ref count */
  (gchar *) "PropertyCancellation",
  NULL,  /* no in args */
  NULL,  /* no out args */
  NULL,  /* no annotations */
};

const GDBusMethodInfo * const org_project_bar_interface_methods[] =
{
  &org_project_bar_interface__hello_world_method,
  &org_project_bar_interface__test_primitive_types_method,
  &org_project_bar_interface__test_non_primitive_types_method,
  &org_project_bar_interface__request_signal_emission_method,
  &org_project_bar_interface__request_multi_property_mods_method,
  &org_project_bar_interface__unimplemented_method_method,
  &org_project_bar_interface__property_cancellation_method,
  NULL,
};

const GDBusAnnotationInfo * const org_project_bar_interface__test_signal_signal_args__val_int32_arg_annotations[] =
{
  NULL,
};

const GDBusArgInfo org_project_bar_interface__test_signal_signal_args__val_int32_arg =
{
  -1,  /* ref count */
  (gchar *) "val_int32",
  (gchar *) "i",
  (GDBusAnnotationInfo **) org_project_bar_interface__test_signal_signal_args__val_int32_arg_annotations,
};

const GDBusAnnotationInfo org_project_bar_interface__test_signal_signal_args__array_of_strings_arg_annotations__key8_annotation =
{
  -1,  /* ref count */
  (gchar *) "Key8",
  (gchar *) "Value8",
  NULL,  /* no annotations */
};

const GDBusAnnotationInfo * const org_project_bar_interface__test_signal_signal_args__array_of_strings_arg_annotations[] =
{
  &org_project_bar_interface__test_signal_signal_args__array_of_strings_arg_annotations__key8_annotation,
  NULL,
};

const GDBusArgInfo org_project_bar_interface__test_signal_signal_args__array_of_strings_arg =
{
  -1,  /* ref count */
  (gchar *) "array_of_strings",
  (gchar *) "as",
  (GDBusAnnotationInfo **) org_project_bar_interface__test_signal_signal_args__array_of_strings_arg_annotations,
};

const GDBusArgInfo org_project_bar_interface__test_signal_signal_args__array_of_bytestrings_arg =
{
  -1,  /* ref count */
  (gchar *) "array_of_bytestrings",
  (gchar *) "aay",
  NULL,  /* no annotations */
};

const GDBusArgInfo org_project_bar_interface__test_signal_signal_args__dict_s_to_pairs_arg =
{
  -1,  /* ref count */
  (gchar *) "dict_s_to_pairs",
  (gchar *) "a{s(ii)}",
  NULL,  /* no annotations */
};

const GDBusArgInfo * const org_project_bar_interface__test_signal_signal_args[] =
{
  &org_project_bar_interface__test_signal_signal_args__val_int32_arg,
  &org_project_bar_interface__test_signal_signal_args__array_of_strings_arg,
  &org_project_bar_interface__test_signal_signal_args__array_of_bytestrings_arg,
  &org_project_bar_interface__test_signal_signal_args__dict_s_to_pairs_arg,
  NULL,
};

const GDBusAnnotationInfo org_project_bar_interface__test_signal_signal_annotations__key4_annotation =
{
  -1,  /* ref count */
  (gchar *) "Key4",
  (gchar *) "Value4",
  NULL,  /* no annotations */
};

const GDBusAnnotationInfo * const org_project_bar_interface__test_signal_signal_annotations[] =
{
  &org_project_bar_interface__test_signal_signal_annotations__key4_annotation,
  NULL,
};

const GDBusSignalInfo org_project_bar_interface__test_signal_signal =
{
  -1,  /* ref count */
  (gchar *) "TestSignal",
  (GDBusArgInfo **) org_project_bar_interface__test_signal_signal_args,
  (GDBusAnnotationInfo **) org_project_bar_interface__test_signal_signal_annotations,
};

const GDBusArgInfo org_project_bar_interface__another_signal_signal_args__word_arg =
{
  -1,  /* ref count */
  (gchar *) "word",
  (gchar *) "s",
  NULL,  /* no annotations */
};

const GDBusArgInfo * const org_project_bar_interface__another_signal_signal_args[] =
{
  &org_project_bar_interface__another_signal_signal_args__word_arg,
  NULL,
};

const GDBusSignalInfo org_project_bar_interface__another_signal_signal =
{
  -1,  /* ref count */
  (gchar *) "AnotherSignal",
  (GDBusArgInfo **) org_project_bar_interface__another_signal_signal_args,
  NULL,  /* no annotations */
};

const GDBusSignalInfo * const org_project_bar_interface_signals[] =
{
  &org_project_bar_interface__test_signal_signal,
  &org_project_bar_interface__another_signal_signal,
  NULL,
};

const GDBusAnnotationInfo * const org_project_bar_interface__y_property_annotations[] =
{
  NULL,
};

const GDBusPropertyInfo org_project_bar_interface__y_property =
{
  -1,  /* ref count */
  (gchar *) "y",
  (gchar *) "y",
  G_DBUS_PROPERTY_INFO_FLAGS_READABLE | G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE,
  (GDBusAnnotationInfo **) org_project_bar_interface__y_property_annotations,
};

const GDBusPropertyInfo org_project_bar_interface__b_property =
{
  -1,  /* ref count */
  (gchar *) "b",
  (gchar *) "b",
  G_DBUS_PROPERTY_INFO_FLAGS_READABLE | G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE,
  NULL,  /* no annotations */
};

const GDBusPropertyInfo org_project_bar_interface__n_property =
{
  -1,  /* ref count */
  (gchar *) "n",
  (gchar *) "n",
  G_DBUS_PROPERTY_INFO_FLAGS_READABLE | G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE,
  NULL,  /* no annotations */
};

const GDBusPropertyInfo org_project_bar_interface__q_property =
{
  -1,  /* ref count */
  (gchar *) "q",
  (gchar *) "q",
  G_DBUS_PROPERTY_INFO_FLAGS_READABLE | G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE,
  NULL,  /* no annotations */
};

const GDBusPropertyInfo org_project_bar_interface__i_property =
{
  -1,  /* ref count */
  (gchar *) "i",
  (gchar *) "i",
  G_DBUS_PROPERTY_INFO_FLAGS_READABLE | G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE,
  NULL,  /* no annotations */
};

const GDBusPropertyInfo org_project_bar_interface__u_property =
{
  -1,  /* ref count */
  (gchar *) "u",
  (gchar *) "u",
  G_DBUS_PROPERTY_INFO_FLAGS_READABLE | G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE,
  NULL,  /* no annotations */
};

const GDBusPropertyInfo org_project_bar_interface__x_property =
{
  -1,  /* ref count */
  (gchar *) "x",
  (gchar *) "x",
  G_DBUS_PROPERTY_INFO_FLAGS_READABLE | G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE,
  NULL,  /* no annotations */
};

const GDBusPropertyInfo org_project_bar_interface__t_property =
{
  -1,  /* ref count */
  (gchar *) "t",
  (gchar *) "t",
  G_DBUS_PROPERTY_INFO_FLAGS_READABLE | G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE,
  NULL,  /* no annotations */
};

const GDBusPropertyInfo org_project_bar_interface__d_property =
{
  -1,  /* ref count */
  (gchar *) "d",
  (gchar *) "d",
  G_DBUS_PROPERTY_INFO_FLAGS_READABLE | G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE,
  NULL,  /* no annotations */
};

const GDBusPropertyInfo org_project_bar_interface__s_property =
{
  -1,  /* ref count */
  (gchar *) "s",
  (gchar *) "s",
  G_DBUS_PROPERTY_INFO_FLAGS_READABLE | G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE,
  NULL,  /* no annotations */
};

const GDBusPropertyInfo org_project_bar_interface__o_property =
{
  -1,  /* ref count */
  (gchar *) "o",
  (gchar *) "o",
  G_DBUS_PROPERTY_INFO_FLAGS_READABLE | G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE,
  NULL,  /* no annotations */
};

const GDBusPropertyInfo org_project_bar_interface__g_property =
{
  -1,  /* ref count */
  (gchar *) "g",
  (gchar *) "g",
  G_DBUS_PROPERTY_INFO_FLAGS_READABLE | G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE,
  NULL,  /* no annotations */
};

const GDBusAnnotationInfo org_project_bar_interface__ay_property_annotations__key5_annotation =
{
  -1,  /* ref count */
  (gchar *) "Key5",
  (gchar *) "Value5",
  NULL,  /* no annotations */
};

const GDBusAnnotationInfo * const org_project_bar_interface__ay_property_annotations[] =
{
  &org_project_bar_interface__ay_property_annotations__key5_annotation,
  NULL,
};

const GDBusPropertyInfo org_project_bar_interface__ay_property =
{
  -1,  /* ref count */
  (gchar *) "ay",
  (gchar *) "ay",
  G_DBUS_PROPERTY_INFO_FLAGS_READABLE | G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE,
  (GDBusAnnotationInfo **) org_project_bar_interface__ay_property_annotations,
};

const GDBusPropertyInfo org_project_bar_interface__as_property =
{
  -1,  /* ref count */
  (gchar *) "as",
  (gchar *) "as",
  G_DBUS_PROPERTY_INFO_FLAGS_READABLE | G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE,
  NULL,  /* no annotations */
};

const GDBusPropertyInfo org_project_bar_interface__aay_property =
{
  -1,  /* ref count */
  (gchar *) "aay",
  (gchar *) "aay",
  G_DBUS_PROPERTY_INFO_FLAGS_READABLE | G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE,
  NULL,  /* no annotations */
};

const GDBusPropertyInfo org_project_bar_interface__ao_property =
{
  -1,  /* ref count */
  (gchar *) "ao",
  (gchar *) "ao",
  G_DBUS_PROPERTY_INFO_FLAGS_READABLE | G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE,
  NULL,  /* no annotations */
};

const GDBusPropertyInfo org_project_bar_interface__ag_property =
{
  -1,  /* ref count */
  (gchar *) "ag",
  (gchar *) "ag",
  G_DBUS_PROPERTY_INFO_FLAGS_READABLE | G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE,
  NULL,  /* no annotations */
};

const GDBusPropertyInfo org_project_bar_interface__finally_normal_name_property =
{
  -1,  /* ref count */
  (gchar *) "FinallyNormalName",
  (gchar *) "s",
  G_DBUS_PROPERTY_INFO_FLAGS_READABLE | G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE,
  NULL,  /* no annotations */
};

const GDBusPropertyInfo org_project_bar_interface__readonly_property_property =
{
  -1,  /* ref count */
  (gchar *) "ReadonlyProperty",
  (gchar *) "s",
  G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
  NULL,  /* no annotations */
};

const GDBusPropertyInfo org_project_bar_interface__writeonly_property_property =
{
  -1,  /* ref count */
  (gchar *) "WriteonlyProperty",
  (gchar *) "s",
  G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE,
  NULL,  /* no annotations */
};

const GDBusAnnotationInfo org_project_bar_interface__quiet_property_annotations__org_freedesktop__dbus__property__emits_changed_signal_annotation =
{
  -1,  /* ref count */
  (gchar *) "org.freedesktop.DBus.Property.EmitsChangedSignal",
  (gchar *) "false",
  NULL,  /* no annotations */
};

const GDBusAnnotationInfo * const org_project_bar_interface__quiet_property_annotations[] =
{
  &org_project_bar_interface__quiet_property_annotations__org_freedesktop__dbus__property__emits_changed_signal_annotation,
  NULL,
};

const GDBusPropertyInfo org_project_bar_interface__quiet_property =
{
  -1,  /* ref count */
  (gchar *) "quiet",
  (gchar *) "s",
  G_DBUS_PROPERTY_INFO_FLAGS_READABLE | G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE,
  (GDBusAnnotationInfo **) org_project_bar_interface__quiet_property_annotations,
};

const GDBusAnnotationInfo org_project_bar_interface__quiet_too_property_annotations__org_freedesktop__dbus__property__emits_changed_signal_annotation =
{
  -1,  /* ref count */
  (gchar *) "org.freedesktop.DBus.Property.EmitsChangedSignal",
  (gchar *) "const",
  NULL,  /* no annotations */
};

const GDBusAnnotationInfo * const org_project_bar_interface__quiet_too_property_annotations[] =
{
  &org_project_bar_interface__quiet_too_property_annotations__org_freedesktop__dbus__property__emits_changed_signal_annotation,
  NULL,
};

const GDBusPropertyInfo org_project_bar_interface__quiet_too_property =
{
  -1,  /* ref count */
  (gchar *) "quiet_too",
  (gchar *) "s",
  G_DBUS_PROPERTY_INFO_FLAGS_READABLE | G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE,
  (GDBusAnnotationInfo **) org_project_bar_interface__quiet_too_property_annotations,
};

const GDBusPropertyInfo org_project_bar_interface__unset_i_property =
{
  -1,  /* ref count */
  (gchar *) "unset_i",
  (gchar *) "i",
  G_DBUS_PROPERTY_INFO_FLAGS_READABLE | G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE,
  NULL,  /* no annotations */
};

const GDBusPropertyInfo org_project_bar_interface__unset_d_property =
{
  -1,  /* ref count */
  (gchar *) "unset_d",
  (gchar *) "d",
  G_DBUS_PROPERTY_INFO_FLAGS_READABLE | G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE,
  NULL,  /* no annotations */
};

const GDBusPropertyInfo org_project_bar_interface__unset_s_property =
{
  -1,  /* ref count */
  (gchar *) "unset_s",
  (gchar *) "s",
  G_DBUS_PROPERTY_INFO_FLAGS_READABLE | G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE,
  NULL,  /* no annotations */
};

const GDBusPropertyInfo org_project_bar_interface__unset_o_property =
{
  -1,  /* ref count */
  (gchar *) "unset_o",
  (gchar *) "o",
  G_DBUS_PROPERTY_INFO_FLAGS_READABLE | G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE,
  NULL,  /* no annotations */
};

const GDBusPropertyInfo org_project_bar_interface__unset_g_property =
{
  -1,  /* ref count */
  (gchar *) "unset_g",
  (gchar *) "g",
  G_DBUS_PROPERTY_INFO_FLAGS_READABLE | G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE,
  NULL,  /* no annotations */
};

const GDBusPropertyInfo org_project_bar_interface__unset_ay_property =
{
  -1,  /* ref count */
  (gchar *) "unset_ay",
  (gchar *) "ay",
  G_DBUS_PROPERTY_INFO_FLAGS_READABLE | G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE,
  NULL,  /* no annotations */
};

const GDBusPropertyInfo org_project_bar_interface__unset_as_property =
{
  -1,  /* ref count */
  (gchar *) "unset_as",
  (gchar *) "as",
  G_DBUS_PROPERTY_INFO_FLAGS_READABLE | G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE,
  NULL,  /* no annotations */
};

const GDBusPropertyInfo org_project_bar_interface__unset_ao_property =
{
  -1,  /* ref count */
  (gchar *) "unset_ao",
  (gchar *) "ao",
  G_DBUS_PROPERTY_INFO_FLAGS_READABLE | G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE,
  NULL,  /* no annotations */
};

const GDBusPropertyInfo org_project_bar_interface__unset_ag_property =
{
  -1,  /* ref count */
  (gchar *) "unset_ag",
  (gchar *) "ag",
  G_DBUS_PROPERTY_INFO_FLAGS_READABLE | G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE,
  NULL,  /* no annotations */
};

const GDBusPropertyInfo org_project_bar_interface__unset_struct_property =
{
  -1,  /* ref count */
  (gchar *) "unset_struct",
  (gchar *) "(idsogayasaoag)",
  G_DBUS_PROPERTY_INFO_FLAGS_READABLE | G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE,
  NULL,  /* no annotations */
};

const GDBusPropertyInfo * const org_project_bar_interface_properties[] =
{
  &org_project_bar_interface__y_property,
  &org_project_bar_interface__b_property,
  &org_project_bar_interface__n_property,
  &org_project_bar_interface__q_property,
  &org_project_bar_interface__i_property,
  &org_project_bar_interface__u_property,
  &org_project_bar_interface__x_property,
  &org_project_bar_interface__t_property,
  &org_project_bar_interface__d_property,
  &org_project_bar_interface__s_property,
  &org_project_bar_interface__o_property,
  &org_project_bar_interface__g_property,
  &org_project_bar_interface__ay_property,
  &org_project_bar_interface__as_property,
  &org_project_bar_interface__aay_property,
  &org_project_bar_interface__ao_property,
  &org_project_bar_interface__ag_property,
  &org_project_bar_interface__finally_normal_name_property,
  &org_project_bar_interface__readonly_property_property,
  &org_project_bar_interface__writeonly_property_property,
  &org_project_bar_interface__quiet_property,
  &org_project_bar_interface__quiet_too_property,
  &org_project_bar_interface__unset_i_property,
  &org_project_bar_interface__unset_d_property,
  &org_project_bar_interface__unset_s_property,
  &org_project_bar_interface__unset_o_property,
  &org_project_bar_interface__unset_g_property,
  &org_project_bar_interface__unset_ay_property,
  &org_project_bar_interface__unset_as_property,
  &org_project_bar_interface__unset_ao_property,
  &org_project_bar_interface__unset_ag_property,
  &org_project_bar_interface__unset_struct_property,
  NULL,
};

const GDBusAnnotationInfo org_project_bar_interface_annotations__key1_annotation =
{
  -1,  /* ref count */
  (gchar *) "Key1",
  (gchar *) "Value1",
  NULL,  /* no annotations */
};

const GDBusAnnotationInfo * const org_project_bar_interface_annotations[] =
{
  &org_project_bar_interface_annotations__key1_annotation,
  NULL,
};

const GDBusInterfaceInfo org_project_bar_interface =
{
  -1,  /* ref count */
  (gchar *) "org.project.Bar",
  (GDBusMethodInfo **) org_project_bar_interface_methods,
  (GDBusSignalInfo **) org_project_bar_interface_signals,
  (GDBusPropertyInfo **) org_project_bar_interface_properties,
  (GDBusAnnotationInfo **) org_project_bar_interface_annotations,
};

/* ------------------------------------------------------------------------ */
/* Definitions for org.project.Bar.Frobnicator */

const GDBusMethodInfo org_project_bar_frobnicator_interface__random_method_method =
{
  -1,  /* ref count */
  (gchar *) "RandomMethod",
  NULL,  /* no in args */
  NULL,  /* no out args */
  NULL,  /* no annotations */
};

const GDBusMethodInfo * const org_project_bar_frobnicator_interface_methods[] =
{
  &org_project_bar_frobnicator_interface__random_method_method,
  NULL,
};

const GDBusInterfaceInfo org_project_bar_frobnicator_interface =
{
  -1,  /* ref count */
  (gchar *) "org.project.Bar.Frobnicator",
  (GDBusMethodInfo **) org_project_bar_frobnicator_interface_methods,
  NULL,  /* no signals */
NULL,  /* no properties */
  NULL,  /* no annotations */
};

/* ------------------------------------------------------------------------ */
/* Definitions for org.project.Baz */

const GDBusInterfaceInfo org_project_baz_interface =
{
  -1,  /* ref count */
  (gchar *) "org.project.Baz",
  NULL,  /* no methods */
  NULL,  /* no signals */
NULL,  /* no properties */
  NULL,  /* no annotations */
};

/* ------------------------------------------------------------------------ */
/* Definitions for com.acme.Coyote */

const GDBusMethodInfo com_acme_coyote_interface__run_method =
{
  -1,  /* ref count */
  (gchar *) "Run",
  NULL,  /* no in args */
  NULL,  /* no out args */
  NULL,  /* no annotations */
};

const GDBusMethodInfo com_acme_coyote_interface__sleep_method =
{
  -1,  /* ref count */
  (gchar *) "Sleep",
  NULL,  /* no in args */
  NULL,  /* no out args */
  NULL,  /* no annotations */
};

const GDBusMethodInfo com_acme_coyote_interface__attack_method =
{
  -1,  /* ref count */
  (gchar *) "Attack",
  NULL,  /* no in args */
  NULL,  /* no out args */
  NULL,  /* no annotations */
};

const GDBusMethodInfo * const com_acme_coyote_interface_methods[] =
{
  &com_acme_coyote_interface__run_method,
  &com_acme_coyote_interface__sleep_method,
  &com_acme_coyote_interface__attack_method,
  NULL,
};

const GDBusSignalInfo com_acme_coyote_interface__surprised_signal =
{
  -1,  /* ref count */
  (gchar *) "Surprised",
  NULL,  /* no args */
  NULL,  /* no annotations */
};

const GDBusSignalInfo * const com_acme_coyote_interface_signals[] =
{
  &com_acme_coyote_interface__surprised_signal,
  NULL,
};

const GDBusPropertyInfo com_acme_coyote_interface__mood_property =
{
  -1,  /* ref count */
  (gchar *) "Mood",
  (gchar *) "s",
  G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
  NULL,  /* no annotations */
};

const GDBusPropertyInfo * const com_acme_coyote_interface_properties[] =
{
  &com_acme_coyote_interface__mood_property,
  NULL,
};

const GDBusInterfaceInfo com_acme_coyote_interface =
{
  -1,  /* ref count */
  (gchar *) "com.acme.Coyote",
  (GDBusMethodInfo **) com_acme_coyote_interface_methods,
  (GDBusSignalInfo **) com_acme_coyote_interface_signals,
  (GDBusPropertyInfo **) com_acme_coyote_interface_properties,
  NULL,  /* no annotations */
};

/* ------------------------------------------------------------------------ */
/* Definitions for com.acme.Rocket */

const GDBusAnnotationInfo * const rocket123_interface__ignite_xyz_method_annotations[] =
{
  NULL,
};

const GDBusMethodInfo rocket123_interface__ignite_xyz_method =
{
  -1,  /* ref count */
  (gchar *) "Ignite",
  NULL,  /* no in args */
  NULL,  /* no out args */
  (GDBusAnnotationInfo **) rocket123_interface__ignite_xyz_method_annotations,
};

const GDBusMethodInfo * const rocket123_interface_methods[] =
{
  &rocket123_interface__ignite_xyz_method,
  NULL,
};

const GDBusAnnotationInfo * const rocket123_interface__exploded_xyz_signal_annotations[] =
{
  NULL,
};

const GDBusSignalInfo rocket123_interface__exploded_xyz_signal =
{
  -1,  /* ref count */
  (gchar *) "Exploded",
  NULL,  /* no args */
  (GDBusAnnotationInfo **) rocket123_interface__exploded_xyz_signal_annotations,
};

const GDBusSignalInfo * const rocket123_interface_signals[] =
{
  &rocket123_interface__exploded_xyz_signal,
  NULL,
};

const GDBusAnnotationInfo * const rocket123_interface__speed_xyz_property_annotations[] =
{
  NULL,
};

const GDBusPropertyInfo rocket123_interface__speed_xyz_property =
{
  -1,  /* ref count */
  (gchar *) "Speed",
  (gchar *) "d",
  G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
  (GDBusAnnotationInfo **) rocket123_interface__speed_xyz_property_annotations,
};

const GDBusPropertyInfo rocket123_interface__direction_property =
{
  -1,  /* ref count */
  (gchar *) "Direction",
  (gchar *) "(ddd)",
  G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
  NULL,  /* no annotations */
};

const GDBusPropertyInfo rocket123_interface__type__property =
{
  -1,  /* ref count */
  (gchar *) "Type",
  (gchar *) "s",
  G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
  NULL,  /* no annotations */
};

const GDBusPropertyInfo * const rocket123_interface_properties[] =
{
  &rocket123_interface__speed_xyz_property,
  &rocket123_interface__direction_property,
  &rocket123_interface__type__property,
  NULL,
};

const GDBusAnnotationInfo * const rocket123_interface_annotations[] =
{
  NULL,
};

const GDBusInterfaceInfo rocket123_interface =
{
  -1,  /* ref count */
  (gchar *) "com.acme.Rocket",
  (GDBusMethodInfo **) rocket123_interface_methods,
  (GDBusSignalInfo **) rocket123_interface_signals,
  (GDBusPropertyInfo **) rocket123_interface_properties,
  (GDBusAnnotationInfo **) rocket123_interface_annotations,
};

/* ------------------------------------------------------------------------ */
/* Definitions for org.project.Bat */

const GDBusAnnotationInfo * const org_project_bat_interface__force_method_method_in_args__force_in_i_arg_annotations[] =
{
  NULL,
};

const GDBusArgInfo org_project_bat_interface__force_method_method_in_args__force_in_i_arg =
{
  -1,  /* ref count */
  (gchar *) "force_in_i",
  (gchar *) "i",
  (GDBusAnnotationInfo **) org_project_bat_interface__force_method_method_in_args__force_in_i_arg_annotations,
};

const GDBusAnnotationInfo * const org_project_bat_interface__force_method_method_in_args__force_in_s_arg_annotations[] =
{
  NULL,
};

const GDBusArgInfo org_project_bat_interface__force_method_method_in_args__force_in_s_arg =
{
  -1,  /* ref count */
  (gchar *) "force_in_s",
  (gchar *) "s",
  (GDBusAnnotationInfo **) org_project_bat_interface__force_method_method_in_args__force_in_s_arg_annotations,
};

const GDBusAnnotationInfo * const org_project_bat_interface__force_method_method_in_args__force_in_ay_arg_annotations[] =
{
  NULL,
};

const GDBusArgInfo org_project_bat_interface__force_method_method_in_args__force_in_ay_arg =
{
  -1,  /* ref count */
  (gchar *) "force_in_ay",
  (gchar *) "ay",
  (GDBusAnnotationInfo **) org_project_bat_interface__force_method_method_in_args__force_in_ay_arg_annotations,
};

const GDBusAnnotationInfo * const org_project_bat_interface__force_method_method_in_args__force_in_struct_arg_annotations[] =
{
  NULL,
};

const GDBusArgInfo org_project_bat_interface__force_method_method_in_args__force_in_struct_arg =
{
  -1,  /* ref count */
  (gchar *) "force_in_struct",
  (gchar *) "(i)",
  (GDBusAnnotationInfo **) org_project_bat_interface__force_method_method_in_args__force_in_struct_arg_annotations,
};

const GDBusArgInfo * const org_project_bat_interface__force_method_method_in_args[] =
{
  &org_project_bat_interface__force_method_method_in_args__force_in_i_arg,
  &org_project_bat_interface__force_method_method_in_args__force_in_s_arg,
  &org_project_bat_interface__force_method_method_in_args__force_in_ay_arg,
  &org_project_bat_interface__force_method_method_in_args__force_in_struct_arg,
  NULL,
};

const GDBusAnnotationInfo * const org_project_bat_interface__force_method_method_out_args__force_out_i_arg_annotations[] =
{
  NULL,
};

const GDBusArgInfo org_project_bat_interface__force_method_method_out_args__force_out_i_arg =
{
  -1,  /* ref count */
  (gchar *) "force_out_i",
  (gchar *) "i",
  (GDBusAnnotationInfo **) org_project_bat_interface__force_method_method_out_args__force_out_i_arg_annotations,
};

const GDBusAnnotationInfo * const org_project_bat_interface__force_method_method_out_args__force_out_s_arg_annotations[] =
{
  NULL,
};

const GDBusArgInfo org_project_bat_interface__force_method_method_out_args__force_out_s_arg =
{
  -1,  /* ref count */
  (gchar *) "force_out_s",
  (gchar *) "s",
  (GDBusAnnotationInfo **) org_project_bat_interface__force_method_method_out_args__force_out_s_arg_annotations,
};

const GDBusAnnotationInfo * const org_project_bat_interface__force_method_method_out_args__force_out_ay_arg_annotations[] =
{
  NULL,
};

const GDBusArgInfo org_project_bat_interface__force_method_method_out_args__force_out_ay_arg =
{
  -1,  /* ref count */
  (gchar *) "force_out_ay",
  (gchar *) "ay",
  (GDBusAnnotationInfo **) org_project_bat_interface__force_method_method_out_args__force_out_ay_arg_annotations,
};

const GDBusAnnotationInfo * const org_project_bat_interface__force_method_method_out_args__force_out_struct_arg_annotations[] =
{
  NULL,
};

const GDBusArgInfo org_project_bat_interface__force_method_method_out_args__force_out_struct_arg =
{
  -1,  /* ref count */
  (gchar *) "force_out_struct",
  (gchar *) "(i)",
  (GDBusAnnotationInfo **) org_project_bat_interface__force_method_method_out_args__force_out_struct_arg_annotations,
};

const GDBusArgInfo * const org_project_bat_interface__force_method_method_out_args[] =
{
  &org_project_bat_interface__force_method_method_out_args__force_out_i_arg,
  &org_project_bat_interface__force_method_method_out_args__force_out_s_arg,
  &org_project_bat_interface__force_method_method_out_args__force_out_ay_arg,
  &org_project_bat_interface__force_method_method_out_args__force_out_struct_arg,
  NULL,
};

const GDBusMethodInfo org_project_bat_interface__force_method_method =
{
  -1,  /* ref count */
  (gchar *) "ForceMethod",
  (GDBusArgInfo **) org_project_bat_interface__force_method_method_in_args,
  (GDBusArgInfo **) org_project_bat_interface__force_method_method_out_args,
  NULL,  /* no annotations */
};

const GDBusMethodInfo * const org_project_bat_interface_methods[] =
{
  &org_project_bat_interface__force_method_method,
  NULL,
};

const GDBusAnnotationInfo * const org_project_bat_interface__force_signal_signal_args__force_i_arg_annotations[] =
{
  NULL,
};

const GDBusArgInfo org_project_bat_interface__force_signal_signal_args__force_i_arg =
{
  -1,  /* ref count */
  (gchar *) "force_i",
  (gchar *) "i",
  (GDBusAnnotationInfo **) org_project_bat_interface__force_signal_signal_args__force_i_arg_annotations,
};

const GDBusAnnotationInfo * const org_project_bat_interface__force_signal_signal_args__force_s_arg_annotations[] =
{
  NULL,
};

const GDBusArgInfo org_project_bat_interface__force_signal_signal_args__force_s_arg =
{
  -1,  /* ref count */
  (gchar *) "force_s",
  (gchar *) "s",
  (GDBusAnnotationInfo **) org_project_bat_interface__force_signal_signal_args__force_s_arg_annotations,
};

const GDBusAnnotationInfo * const org_project_bat_interface__force_signal_signal_args__force_ay_arg_annotations[] =
{
  NULL,
};

const GDBusArgInfo org_project_bat_interface__force_signal_signal_args__force_ay_arg =
{
  -1,  /* ref count */
  (gchar *) "force_ay",
  (gchar *) "ay",
  (GDBusAnnotationInfo **) org_project_bat_interface__force_signal_signal_args__force_ay_arg_annotations,
};

const GDBusAnnotationInfo * const org_project_bat_interface__force_signal_signal_args__force_struct_arg_annotations[] =
{
  NULL,
};

const GDBusArgInfo org_project_bat_interface__force_signal_signal_args__force_struct_arg =
{
  -1,  /* ref count */
  (gchar *) "force_struct",
  (gchar *) "(i)",
  (GDBusAnnotationInfo **) org_project_bat_interface__force_signal_signal_args__force_struct_arg_annotations,
};

const GDBusArgInfo * const org_project_bat_interface__force_signal_signal_args[] =
{
  &org_project_bat_interface__force_signal_signal_args__force_i_arg,
  &org_project_bat_interface__force_signal_signal_args__force_s_arg,
  &org_project_bat_interface__force_signal_signal_args__force_ay_arg,
  &org_project_bat_interface__force_signal_signal_args__force_struct_arg,
  NULL,
};

const GDBusSignalInfo org_project_bat_interface__force_signal_signal =
{
  -1,  /* ref count */
  (gchar *) "ForceSignal",
  (GDBusArgInfo **) org_project_bat_interface__force_signal_signal_args,
  NULL,  /* no annotations */
};

const GDBusSignalInfo * const org_project_bat_interface_signals[] =
{
  &org_project_bat_interface__force_signal_signal,
  NULL,
};

const GDBusAnnotationInfo * const org_project_bat_interface__force_i_property_annotations[] =
{
  NULL,
};

const GDBusPropertyInfo org_project_bat_interface__force_i_property =
{
  -1,  /* ref count */
  (gchar *) "force_i",
  (gchar *) "i",
  G_DBUS_PROPERTY_INFO_FLAGS_READABLE | G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE,
  (GDBusAnnotationInfo **) org_project_bat_interface__force_i_property_annotations,
};

const GDBusAnnotationInfo * const org_project_bat_interface__force_s_property_annotations[] =
{
  NULL,
};

const GDBusPropertyInfo org_project_bat_interface__force_s_property =
{
  -1,  /* ref count */
  (gchar *) "force_s",
  (gchar *) "s",
  G_DBUS_PROPERTY_INFO_FLAGS_READABLE | G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE,
  (GDBusAnnotationInfo **) org_project_bat_interface__force_s_property_annotations,
};

const GDBusAnnotationInfo * const org_project_bat_interface__force_ay_property_annotations[] =
{
  NULL,
};

const GDBusPropertyInfo org_project_bat_interface__force_ay_property =
{
  -1,  /* ref count */
  (gchar *) "force_ay",
  (gchar *) "ay",
  G_DBUS_PROPERTY_INFO_FLAGS_READABLE | G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE,
  (GDBusAnnotationInfo **) org_project_bat_interface__force_ay_property_annotations,
};

const GDBusAnnotationInfo * const org_project_bat_interface__force_struct_property_annotations[] =
{
  NULL,
};

const GDBusPropertyInfo org_project_bat_interface__force_struct_property =
{
  -1,  /* ref count */
  (gchar *) "force_struct",
  (gchar *) "(i)",
  G_DBUS_PROPERTY_INFO_FLAGS_READABLE | G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE,
  (GDBusAnnotationInfo **) org_project_bat_interface__force_struct_property_annotations,
};

const GDBusPropertyInfo * const org_project_bat_interface_properties[] =
{
  &org_project_bat_interface__force_i_property,
  &org_project_bat_interface__force_s_property,
  &org_project_bat_interface__force_ay_property,
  &org_project_bat_interface__force_struct_property,
  NULL,
};

const GDBusInterfaceInfo org_project_bat_interface =
{
  -1,  /* ref count */
  (gchar *) "org.project.Bat",
  (GDBusMethodInfo **) org_project_bat_interface_methods,
  (GDBusSignalInfo **) org_project_bat_interface_signals,
  (GDBusPropertyInfo **) org_project_bat_interface_properties,
  NULL,  /* no annotations */
};

/* ------------------------------------------------------------------------ */
/* Definitions for org.project.Authorize */

const GDBusMethodInfo org_project_authorize_interface__check_not_authorized_method =
{
  -1,  /* ref count */
  (gchar *) "CheckNotAuthorized",
  NULL,  /* no in args */
  NULL,  /* no out args */
  NULL,  /* no annotations */
};

const GDBusMethodInfo org_project_authorize_interface__check_authorized_method =
{
  -1,  /* ref count */
  (gchar *) "CheckAuthorized",
  NULL,  /* no in args */
  NULL,  /* no out args */
  NULL,  /* no annotations */
};

const GDBusMethodInfo org_project_authorize_interface__check_not_authorized_from_object_method =
{
  -1,  /* ref count */
  (gchar *) "CheckNotAuthorizedFromObject",
  NULL,  /* no in args */
  NULL,  /* no out args */
  NULL,  /* no annotations */
};

const GDBusMethodInfo * const org_project_authorize_interface_methods[] =
{
  &org_project_authorize_interface__check_not_authorized_method,
  &org_project_authorize_interface__check_authorized_method,
  &org_project_authorize_interface__check_not_authorized_from_object_method,
  NULL,
};

const GDBusInterfaceInfo org_project_authorize_interface =
{
  -1,  /* ref count */
  (gchar *) "org.project.Authorize",
  (GDBusMethodInfo **) org_project_authorize_interface_methods,
  NULL,  /* no signals */
NULL,  /* no properties */
  NULL,  /* no annotations */
};

/* ------------------------------------------------------------------------ */
/* Definitions for org.project.MethodThreads */

const GDBusArgInfo org_project_method_threads_interface__get_self_method_out_args__self_pointer_arg =
{
  -1,  /* ref count */
  (gchar *) "self_pointer",
  (gchar *) "s",
  NULL,  /* no annotations */
};

const GDBusArgInfo * const org_project_method_threads_interface__get_self_method_out_args[] =
{
  &org_project_method_threads_interface__get_self_method_out_args__self_pointer_arg,
  NULL,
};

const GDBusMethodInfo org_project_method_threads_interface__get_self_method =
{
  -1,  /* ref count */
  (gchar *) "GetSelf",
  NULL,  /* no in args */
  (GDBusArgInfo **) org_project_method_threads_interface__get_self_method_out_args,
  NULL,  /* no annotations */
};

const GDBusMethodInfo * const org_project_method_threads_interface_methods[] =
{
  &org_project_method_threads_interface__get_self_method,
  NULL,
};

const GDBusInterfaceInfo org_project_method_threads_interface =
{
  -1,  /* ref count */
  (gchar *) "org.project.MethodThreads",
  (GDBusMethodInfo **) org_project_method_threads_interface_methods,
  NULL,  /* no signals */
NULL,  /* no properties */
  NULL,  /* no annotations */
};

/* ------------------------------------------------------------------------ */
/* Definitions for org.project.InlineDocs */

const GDBusArgInfo org_project_inline_docs_interface__foo_method_method_in_args__greeting_arg =
{
  -1,  /* ref count */
  (gchar *) "greeting",
  (gchar *) "s",
  NULL,  /* no annotations */
};

const GDBusArgInfo * const org_project_inline_docs_interface__foo_method_method_in_args[] =
{
  &org_project_inline_docs_interface__foo_method_method_in_args__greeting_arg,
  NULL,
};

const GDBusArgInfo org_project_inline_docs_interface__foo_method_method_out_args__response_arg =
{
  -1,  /* ref count */
  (gchar *) "response",
  (gchar *) "s",
  NULL,  /* no annotations */
};

const GDBusArgInfo * const org_project_inline_docs_interface__foo_method_method_out_args[] =
{
  &org_project_inline_docs_interface__foo_method_method_out_args__response_arg,
  NULL,
};

const GDBusMethodInfo org_project_inline_docs_interface__foo_method_method =
{
  -1,  /* ref count */
  (gchar *) "FooMethod",
  (GDBusArgInfo **) org_project_inline_docs_interface__foo_method_method_in_args,
  (GDBusArgInfo **) org_project_inline_docs_interface__foo_method_method_out_args,
  NULL,  /* no annotations */
};

const GDBusArgInfo org_project_inline_docs_interface__method2_method_in_args__greeting_arg =
{
  -1,  /* ref count */
  (gchar *) "greeting",
  (gchar *) "s",
  NULL,  /* no annotations */
};

const GDBusArgInfo * const org_project_inline_docs_interface__method2_method_in_args[] =
{
  &org_project_inline_docs_interface__method2_method_in_args__greeting_arg,
  NULL,
};

const GDBusArgInfo org_project_inline_docs_interface__method2_method_out_args__response_arg =
{
  -1,  /* ref count */
  (gchar *) "response",
  (gchar *) "s",
  NULL,  /* no annotations */
};

const GDBusArgInfo * const org_project_inline_docs_interface__method2_method_out_args[] =
{
  &org_project_inline_docs_interface__method2_method_out_args__response_arg,
  NULL,
};

const GDBusMethodInfo org_project_inline_docs_interface__method2_method =
{
  -1,  /* ref count */
  (gchar *) "Method2",
  (GDBusArgInfo **) org_project_inline_docs_interface__method2_method_in_args,
  (GDBusArgInfo **) org_project_inline_docs_interface__method2_method_out_args,
  NULL,  /* no annotations */
};

const GDBusMethodInfo * const org_project_inline_docs_interface_methods[] =
{
  &org_project_inline_docs_interface__foo_method_method,
  &org_project_inline_docs_interface__method2_method,
  NULL,
};

const GDBusArgInfo org_project_inline_docs_interface__bar_signal_signal_args__blah_arg =
{
  -1,  /* ref count */
  (gchar *) "blah",
  (gchar *) "s",
  NULL,  /* no annotations */
};

const GDBusArgInfo org_project_inline_docs_interface__bar_signal_signal_args__boo_arg =
{
  -1,  /* ref count */
  (gchar *) "boo",
  (gchar *) "s",
  NULL,  /* no annotations */
};

const GDBusArgInfo * const org_project_inline_docs_interface__bar_signal_signal_args[] =
{
  &org_project_inline_docs_interface__bar_signal_signal_args__blah_arg,
  &org_project_inline_docs_interface__bar_signal_signal_args__boo_arg,
  NULL,
};

const GDBusSignalInfo org_project_inline_docs_interface__bar_signal_signal =
{
  -1,  /* ref count */
  (gchar *) "BarSignal",
  (GDBusArgInfo **) org_project_inline_docs_interface__bar_signal_signal_args,
  NULL,  /* no annotations */
};

const GDBusSignalInfo * const org_project_inline_docs_interface_signals[] =
{
  &org_project_inline_docs_interface__bar_signal_signal,
  NULL,
};

const GDBusPropertyInfo org_project_inline_docs_interface__baz_property_property =
{
  -1,  /* ref count */
  (gchar *) "BazProperty",
  (gchar *) "s",
  G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
  NULL,  /* no annotations */
};

const GDBusPropertyInfo org_project_inline_docs_interface__property2_property =
{
  -1,  /* ref count */
  (gchar *) "Property2",
  (gchar *) "s",
  G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
  NULL,  /* no annotations */
};

const GDBusPropertyInfo org_project_inline_docs_interface__property3_property =
{
  -1,  /* ref count */
  (gchar *) "Property3",
  (gchar *) "s",
  G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
  NULL,  /* no annotations */
};

const GDBusPropertyInfo org_project_inline_docs_interface__property4_property =
{
  -1,  /* ref count */
  (gchar *) "Property4",
  (gchar *) "s",
  G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
  NULL,  /* no annotations */
};

const GDBusPropertyInfo org_project_inline_docs_interface__property5_property =
{
  -1,  /* ref count */
  (gchar *) "Property5",
  (gchar *) "s",
  G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
  NULL,  /* no annotations */
};

const GDBusPropertyInfo org_project_inline_docs_interface__fancy_property_property =
{
  -1,  /* ref count */
  (gchar *) "FancyProperty",
  (gchar *) "s",
  G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
  NULL,  /* no annotations */
};

const GDBusPropertyInfo * const org_project_inline_docs_interface_properties[] =
{
  &org_project_inline_docs_interface__baz_property_property,
  &org_project_inline_docs_interface__property2_property,
  &org_project_inline_docs_interface__property3_property,
  &org_project_inline_docs_interface__property4_property,
  &org_project_inline_docs_interface__property5_property,
  &org_project_inline_docs_interface__fancy_property_property,
  NULL,
};

const GDBusInterfaceInfo org_project_inline_docs_interface =
{
  -1,  /* ref count */
  (gchar *) "org.project.InlineDocs",
  (GDBusMethodInfo **) org_project_inline_docs_interface_methods,
  (GDBusSignalInfo **) org_project_inline_docs_interface_signals,
  (GDBusPropertyInfo **) org_project_inline_docs_interface_properties,
  NULL,  /* no annotations */
};

/* ------------------------------------------------------------------------ */
/* Definitions for ChangingInterfaceV1 */

const GDBusMethodInfo changing_interface_v1_interface__foo_method_method =
{
  -1,  /* ref count */
  (gchar *) "FooMethod",
  NULL,  /* no in args */
  NULL,  /* no out args */
  NULL,  /* no annotations */
};

const GDBusMethodInfo changing_interface_v1_interface__bar_method_method =
{
  -1,  /* ref count */
  (gchar *) "BarMethod",
  NULL,  /* no in args */
  NULL,  /* no out args */
  NULL,  /* no annotations */
};

const GDBusMethodInfo changing_interface_v1_interface__baz_method_method =
{
  -1,  /* ref count */
  (gchar *) "BazMethod",
  NULL,  /* no in args */
  NULL,  /* no out args */
  NULL,  /* no annotations */
};

const GDBusMethodInfo * const changing_interface_v1_interface_methods[] =
{
  &changing_interface_v1_interface__foo_method_method,
  &changing_interface_v1_interface__bar_method_method,
  &changing_interface_v1_interface__baz_method_method,
  NULL,
};

const GDBusSignalInfo changing_interface_v1_interface__foo_signal_signal =
{
  -1,  /* ref count */
  (gchar *) "FooSignal",
  NULL,  /* no args */
  NULL,  /* no annotations */
};

const GDBusSignalInfo changing_interface_v1_interface__bar_signal_signal =
{
  -1,  /* ref count */
  (gchar *) "BarSignal",
  NULL,  /* no args */
  NULL,  /* no annotations */
};

const GDBusSignalInfo changing_interface_v1_interface__baz_signal_signal =
{
  -1,  /* ref count */
  (gchar *) "BazSignal",
  NULL,  /* no args */
  NULL,  /* no annotations */
};

const GDBusSignalInfo * const changing_interface_v1_interface_signals[] =
{
  &changing_interface_v1_interface__foo_signal_signal,
  &changing_interface_v1_interface__bar_signal_signal,
  &changing_interface_v1_interface__baz_signal_signal,
  NULL,
};

const GDBusInterfaceInfo changing_interface_v1_interface =
{
  -1,  /* ref count */
  (gchar *) "ChangingInterfaceV1",
  (GDBusMethodInfo **) changing_interface_v1_interface_methods,
  (GDBusSignalInfo **) changing_interface_v1_interface_signals,
NULL,  /* no properties */
  NULL,  /* no annotations */
};

/* ------------------------------------------------------------------------ */
/* Definitions for ChangingInterfaceV2 */

const GDBusMethodInfo changing_interface_v2_interface__new_method_in2_method =
{
  -1,  /* ref count */
  (gchar *) "NewMethodIn2",
  NULL,  /* no in args */
  NULL,  /* no out args */
  NULL,  /* no annotations */
};

const GDBusMethodInfo changing_interface_v2_interface__baz_method_method =
{
  -1,  /* ref count */
  (gchar *) "BazMethod",
  NULL,  /* no in args */
  NULL,  /* no out args */
  NULL,  /* no annotations */
};

const GDBusMethodInfo changing_interface_v2_interface__bar_method_method =
{
  -1,  /* ref count */
  (gchar *) "BarMethod",
  NULL,  /* no in args */
  NULL,  /* no out args */
  NULL,  /* no annotations */
};

const GDBusMethodInfo changing_interface_v2_interface__foo_method_method =
{
  -1,  /* ref count */
  (gchar *) "FooMethod",
  NULL,  /* no in args */
  NULL,  /* no out args */
  NULL,  /* no annotations */
};

const GDBusMethodInfo * const changing_interface_v2_interface_methods[] =
{
  &changing_interface_v2_interface__new_method_in2_method,
  &changing_interface_v2_interface__baz_method_method,
  &changing_interface_v2_interface__bar_method_method,
  &changing_interface_v2_interface__foo_method_method,
  NULL,
};

const GDBusSignalInfo changing_interface_v2_interface__new_signal_in2_signal =
{
  -1,  /* ref count */
  (gchar *) "NewSignalIn2",
  NULL,  /* no args */
  NULL,  /* no annotations */
};

const GDBusSignalInfo changing_interface_v2_interface__baz_signal_signal =
{
  -1,  /* ref count */
  (gchar *) "BazSignal",
  NULL,  /* no args */
  NULL,  /* no annotations */
};

const GDBusSignalInfo changing_interface_v2_interface__bar_signal_signal =
{
  -1,  /* ref count */
  (gchar *) "BarSignal",
  NULL,  /* no args */
  NULL,  /* no annotations */
};

const GDBusSignalInfo changing_interface_v2_interface__foo_signal_signal =
{
  -1,  /* ref count */
  (gchar *) "FooSignal",
  NULL,  /* no args */
  NULL,  /* no annotations */
};

const GDBusSignalInfo * const changing_interface_v2_interface_signals[] =
{
  &changing_interface_v2_interface__new_signal_in2_signal,
  &changing_interface_v2_interface__baz_signal_signal,
  &changing_interface_v2_interface__bar_signal_signal,
  &changing_interface_v2_interface__foo_signal_signal,
  NULL,
};

const GDBusInterfaceInfo changing_interface_v2_interface =
{
  -1,  /* ref count */
  (gchar *) "ChangingInterfaceV2",
  (GDBusMethodInfo **) changing_interface_v2_interface_methods,
  (GDBusSignalInfo **) changing_interface_v2_interface_signals,
NULL,  /* no properties */
  NULL,  /* no annotations */
};

/* ------------------------------------------------------------------------ */
/* Definitions for ChangingInterfaceV10 */

const GDBusAnnotationInfo * const changing_interface_v10_interface__added_method_in10_method_annotations[] =
{
  NULL,
};

const GDBusMethodInfo changing_interface_v10_interface__added_method_in10_method =
{
  -1,  /* ref count */
  (gchar *) "AddedMethodIn10",
  NULL,  /* no in args */
  NULL,  /* no out args */
  (GDBusAnnotationInfo **) changing_interface_v10_interface__added_method_in10_method_annotations,
};

const GDBusMethodInfo changing_interface_v10_interface__new_method_in2_method =
{
  -1,  /* ref count */
  (gchar *) "NewMethodIn2",
  NULL,  /* no in args */
  NULL,  /* no out args */
  NULL,  /* no annotations */
};

const GDBusMethodInfo changing_interface_v10_interface__baz_method_method =
{
  -1,  /* ref count */
  (gchar *) "BazMethod",
  NULL,  /* no in args */
  NULL,  /* no out args */
  NULL,  /* no annotations */
};

const GDBusMethodInfo changing_interface_v10_interface__bar_method_method =
{
  -1,  /* ref count */
  (gchar *) "BarMethod",
  NULL,  /* no in args */
  NULL,  /* no out args */
  NULL,  /* no annotations */
};

const GDBusMethodInfo changing_interface_v10_interface__foo_method_method =
{
  -1,  /* ref count */
  (gchar *) "FooMethod",
  NULL,  /* no in args */
  NULL,  /* no out args */
  NULL,  /* no annotations */
};

const GDBusMethodInfo * const changing_interface_v10_interface_methods[] =
{
  &changing_interface_v10_interface__added_method_in10_method,
  &changing_interface_v10_interface__new_method_in2_method,
  &changing_interface_v10_interface__baz_method_method,
  &changing_interface_v10_interface__bar_method_method,
  &changing_interface_v10_interface__foo_method_method,
  NULL,
};

const GDBusSignalInfo changing_interface_v10_interface__added_signal_in10_signal =
{
  -1,  /* ref count */
  (gchar *) "AddedSignalIn10",
  NULL,  /* no args */
  NULL,  /* no annotations */
};

const GDBusSignalInfo changing_interface_v10_interface__new_signal_in2_signal =
{
  -1,  /* ref count */
  (gchar *) "NewSignalIn2",
  NULL,  /* no args */
  NULL,  /* no annotations */
};

const GDBusSignalInfo changing_interface_v10_interface__baz_signal_signal =
{
  -1,  /* ref count */
  (gchar *) "BazSignal",
  NULL,  /* no args */
  NULL,  /* no annotations */
};

const GDBusSignalInfo changing_interface_v10_interface__bar_signal_signal =
{
  -1,  /* ref count */
  (gchar *) "BarSignal",
  NULL,  /* no args */
  NULL,  /* no annotations */
};

const GDBusSignalInfo changing_interface_v10_interface__foo_signal_signal =
{
  -1,  /* ref count */
  (gchar *) "FooSignal",
  NULL,  /* no args */
  NULL,  /* no annotations */
};

const GDBusSignalInfo * const changing_interface_v10_interface_signals[] =
{
  &changing_interface_v10_interface__added_signal_in10_signal,
  &changing_interface_v10_interface__new_signal_in2_signal,
  &changing_interface_v10_interface__baz_signal_signal,
  &changing_interface_v10_interface__bar_signal_signal,
  &changing_interface_v10_interface__foo_signal_signal,
  NULL,
};

const GDBusInterfaceInfo changing_interface_v10_interface =
{
  -1,  /* ref count */
  (gchar *) "ChangingInterfaceV10",
  (GDBusMethodInfo **) changing_interface_v10_interface_methods,
  (GDBusSignalInfo **) changing_interface_v10_interface_signals,
NULL,  /* no properties */
  NULL,  /* no annotations */
};

/* ------------------------------------------------------------------------ */
/* Definitions for TestUglyCaseInterface */

const GDBusAnnotationInfo * const test_ugly_case_interface_interface__get_iscsi_servers_method_annotations[] =
{
  NULL,
};

const GDBusMethodInfo test_ugly_case_interface_interface__get_iscsi_servers_method =
{
  -1,  /* ref count */
  (gchar *) "GetiSCSIServers",
  NULL,  /* no in args */
  NULL,  /* no out args */
  (GDBusAnnotationInfo **) test_ugly_case_interface_interface__get_iscsi_servers_method_annotations,
};

const GDBusMethodInfo * const test_ugly_case_interface_interface_methods[] =
{
  &test_ugly_case_interface_interface__get_iscsi_servers_method,
  NULL,
};

const GDBusAnnotationInfo * const test_ugly_case_interface_interface__servers_updated_now_signal_annotations[] =
{
  NULL,
};

const GDBusSignalInfo test_ugly_case_interface_interface__servers_updated_now_signal =
{
  -1,  /* ref count */
  (gchar *) "serversUPDATEDNOW",
  NULL,  /* no args */
  (GDBusAnnotationInfo **) test_ugly_case_interface_interface__servers_updated_now_signal_annotations,
};

const GDBusSignalInfo * const test_ugly_case_interface_interface_signals[] =
{
  &test_ugly_case_interface_interface__servers_updated_now_signal,
  NULL,
};

const GDBusAnnotationInfo * const test_ugly_case_interface_interface__ugly_name_property_annotations[] =
{
  NULL,
};

const GDBusPropertyInfo test_ugly_case_interface_interface__ugly_name_property =
{
  -1,  /* ref count */
  (gchar *) "UGLYNAME",
  (gchar *) "i",
  G_DBUS_PROPERTY_INFO_FLAGS_READABLE | G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE,
  (GDBusAnnotationInfo **) test_ugly_case_interface_interface__ugly_name_property_annotations,
};

const GDBusPropertyInfo * const test_ugly_case_interface_interface_properties[] =
{
  &test_ugly_case_interface_interface__ugly_name_property,
  NULL,
};

const GDBusAnnotationInfo * const test_ugly_case_interface_interface_annotations[] =
{
  NULL,
};

const GDBusInterfaceInfo test_ugly_case_interface_interface =
{
  -1,  /* ref count */
  (gchar *) "TestUglyCaseInterface",
  (GDBusMethodInfo **) test_ugly_case_interface_interface_methods,
  (GDBusSignalInfo **) test_ugly_case_interface_interface_signals,
  (GDBusPropertyInfo **) test_ugly_case_interface_interface_properties,
  (GDBusAnnotationInfo **) test_ugly_case_interface_interface_annotations,
};

/* ------------------------------------------------------------------------ */
/* Definitions for OldieInterface */

const GDBusAnnotationInfo oldie_interface_interface__foo_method_annotations__org_freedesktop__dbus__deprecated_annotation =
{
  -1,  /* ref count */
  (gchar *) "org.freedesktop.DBus.Deprecated",
  (gchar *) "true",
  NULL,  /* no annotations */
};

const GDBusAnnotationInfo * const oldie_interface_interface__foo_method_annotations[] =
{
  &oldie_interface_interface__foo_method_annotations__org_freedesktop__dbus__deprecated_annotation,
  NULL,
};

const GDBusMethodInfo oldie_interface_interface__foo_method =
{
  -1,  /* ref count */
  (gchar *) "Foo",
  NULL,  /* no in args */
  NULL,  /* no out args */
  (GDBusAnnotationInfo **) oldie_interface_interface__foo_method_annotations,
};

const GDBusMethodInfo * const oldie_interface_interface_methods[] =
{
  &oldie_interface_interface__foo_method,
  NULL,
};

const GDBusAnnotationInfo oldie_interface_interface__bar_signal_annotations__org_freedesktop__dbus__deprecated_annotation =
{
  -1,  /* ref count */
  (gchar *) "org.freedesktop.DBus.Deprecated",
  (gchar *) "true",
  NULL,  /* no annotations */
};

const GDBusAnnotationInfo * const oldie_interface_interface__bar_signal_annotations[] =
{
  &oldie_interface_interface__bar_signal_annotations__org_freedesktop__dbus__deprecated_annotation,
  NULL,
};

const GDBusSignalInfo oldie_interface_interface__bar_signal =
{
  -1,  /* ref count */
  (gchar *) "Bar",
  NULL,  /* no args */
  (GDBusAnnotationInfo **) oldie_interface_interface__bar_signal_annotations,
};

const GDBusSignalInfo * const oldie_interface_interface_signals[] =
{
  &oldie_interface_interface__bar_signal,
  NULL,
};

const GDBusAnnotationInfo oldie_interface_interface__bat_property_annotations__org_freedesktop__dbus__deprecated_annotation =
{
  -1,  /* ref count */
  (gchar *) "org.freedesktop.DBus.Deprecated",
  (gchar *) "true",
  NULL,  /* no annotations */
};

const GDBusAnnotationInfo * const oldie_interface_interface__bat_property_annotations[] =
{
  &oldie_interface_interface__bat_property_annotations__org_freedesktop__dbus__deprecated_annotation,
  NULL,
};

const GDBusPropertyInfo oldie_interface_interface__bat_property =
{
  -1,  /* ref count */
  (gchar *) "Bat",
  (gchar *) "i",
  G_DBUS_PROPERTY_INFO_FLAGS_READABLE | G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE,
  (GDBusAnnotationInfo **) oldie_interface_interface__bat_property_annotations,
};

const GDBusPropertyInfo * const oldie_interface_interface_properties[] =
{
  &oldie_interface_interface__bat_property,
  NULL,
};

const GDBusAnnotationInfo oldie_interface_interface_annotations__org_freedesktop__dbus__deprecated_annotation =
{
  -1,  /* ref count */
  (gchar *) "org.freedesktop.DBus.Deprecated",
  (gchar *) "true",
  NULL,  /* no annotations */
};

const GDBusAnnotationInfo * const oldie_interface_interface_annotations[] =
{
  &oldie_interface_interface_annotations__org_freedesktop__dbus__deprecated_annotation,
  NULL,
};

const GDBusInterfaceInfo oldie_interface_interface =
{
  -1,  /* ref count */
  (gchar *) "OldieInterface",
  (GDBusMethodInfo **) oldie_interface_interface_methods,
  (GDBusSignalInfo **) oldie_interface_interface_signals,
  (GDBusPropertyInfo **) oldie_interface_interface_properties,
  (GDBusAnnotationInfo **) oldie_interface_interface_annotations,
};

/* ------------------------------------------------------------------------ */
/* Definitions for UnknownXmlTags */

const GDBusArgInfo unknown_xml_tags_interface__can_set_timezone_method_out_args__value_arg =
{
  -1,  /* ref count */
  (gchar *) "value",
  (gchar *) "i",
  NULL,  /* no annotations */
};

const GDBusArgInfo * const unknown_xml_tags_interface__can_set_timezone_method_out_args[] =
{
  &unknown_xml_tags_interface__can_set_timezone_method_out_args__value_arg,
  NULL,
};

const GDBusAnnotationInfo unknown_xml_tags_interface__can_set_timezone_method_annotations__org_freedesktop__dbus__glib__async_annotation =
{
  -1,  /* ref count */
  (gchar *) "org.freedesktop.DBus.GLib.Async",
  (gchar *) "",
  NULL,  /* no annotations */
};

const GDBusAnnotationInfo * const unknown_xml_tags_interface__can_set_timezone_method_annotations[] =
{
  &unknown_xml_tags_interface__can_set_timezone_method_annotations__org_freedesktop__dbus__glib__async_annotation,
  NULL,
};

const GDBusMethodInfo unknown_xml_tags_interface__can_set_timezone_method =
{
  -1,  /* ref count */
  (gchar *) "CanSetTimezone",
  NULL,  /* no in args */
  (GDBusArgInfo **) unknown_xml_tags_interface__can_set_timezone_method_out_args,
  (GDBusAnnotationInfo **) unknown_xml_tags_interface__can_set_timezone_method_annotations,
};

const GDBusMethodInfo * const unknown_xml_tags_interface_methods[] =
{
  &unknown_xml_tags_interface__can_set_timezone_method,
  NULL,
};

const GDBusSignalInfo unknown_xml_tags_interface__some_signal_signal =
{
  -1,  /* ref count */
  (gchar *) "SomeSignal",
  NULL,  /* no args */
  NULL,  /* no annotations */
};

const GDBusSignalInfo * const unknown_xml_tags_interface_signals[] =
{
  &unknown_xml_tags_interface__some_signal_signal,
  NULL,
};

const GDBusPropertyInfo unknown_xml_tags_interface__some_property_property =
{
  -1,  /* ref count */
  (gchar *) "SomeProperty",
  (gchar *) "s",
  G_DBUS_PROPERTY_INFO_FLAGS_READABLE | G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE,
  NULL,  /* no annotations */
};

const GDBusPropertyInfo * const unknown_xml_tags_interface_properties[] =
{
  &unknown_xml_tags_interface__some_property_property,
  NULL,
};

const GDBusInterfaceInfo unknown_xml_tags_interface =
{
  -1,  /* ref count */
  (gchar *) "UnknownXmlTags",
  (GDBusMethodInfo **) unknown_xml_tags_interface_methods,
  (GDBusSignalInfo **) unknown_xml_tags_interface_signals,
  (GDBusPropertyInfo **) unknown_xml_tags_interface_properties,
  NULL,  /* no annotations */
};

/* ------------------------------------------------------------------------ */
/* Definitions for FDPassing */

const GDBusArgInfo fdpassing_interface__hello_fd_method_in_args__greeting_arg =
{
  -1,  /* ref count */
  (gchar *) "greeting",
  (gchar *) "s",
  NULL,  /* no annotations */
};

const GDBusArgInfo * const fdpassing_interface__hello_fd_method_in_args[] =
{
  &fdpassing_interface__hello_fd_method_in_args__greeting_arg,
  NULL,
};

const GDBusArgInfo fdpassing_interface__hello_fd_method_out_args__response_arg =
{
  -1,  /* ref count */
  (gchar *) "response",
  (gchar *) "s",
  NULL,  /* no annotations */
};

const GDBusArgInfo * const fdpassing_interface__hello_fd_method_out_args[] =
{
  &fdpassing_interface__hello_fd_method_out_args__response_arg,
  NULL,
};

const GDBusAnnotationInfo * const fdpassing_interface__hello_fd_method_annotations[] =
{
  NULL,
};

const GDBusMethodInfo fdpassing_interface__hello_fd_method =
{
  -1,  /* ref count */
  (gchar *) "HelloFD",
  (GDBusArgInfo **) fdpassing_interface__hello_fd_method_in_args,
  (GDBusArgInfo **) fdpassing_interface__hello_fd_method_out_args,
  (GDBusAnnotationInfo **) fdpassing_interface__hello_fd_method_annotations,
};

const GDBusArgInfo fdpassing_interface__no_annotation_method_in_args__greeting_arg =
{
  -1,  /* ref count */
  (gchar *) "greeting",
  (gchar *) "h",
  NULL,  /* no annotations */
};

const GDBusArgInfo fdpassing_interface__no_annotation_method_in_args__greeting_locale_arg =
{
  -1,  /* ref count */
  (gchar *) "greeting_locale",
  (gchar *) "s",
  NULL,  /* no annotations */
};

const GDBusArgInfo * const fdpassing_interface__no_annotation_method_in_args[] =
{
  &fdpassing_interface__no_annotation_method_in_args__greeting_arg,
  &fdpassing_interface__no_annotation_method_in_args__greeting_locale_arg,
  NULL,
};

const GDBusArgInfo fdpassing_interface__no_annotation_method_out_args__response_arg =
{
  -1,  /* ref count */
  (gchar *) "response",
  (gchar *) "h",
  NULL,  /* no annotations */
};

const GDBusArgInfo fdpassing_interface__no_annotation_method_out_args__response_locale_arg =
{
  -1,  /* ref count */
  (gchar *) "response_locale",
  (gchar *) "s",
  NULL,  /* no annotations */
};

const GDBusArgInfo * const fdpassing_interface__no_annotation_method_out_args[] =
{
  &fdpassing_interface__no_annotation_method_out_args__response_arg,
  &fdpassing_interface__no_annotation_method_out_args__response_locale_arg,
  NULL,
};

const GDBusMethodInfo fdpassing_interface__no_annotation_method =
{
  -1,  /* ref count */
  (gchar *) "NoAnnotation",
  (GDBusArgInfo **) fdpassing_interface__no_annotation_method_in_args,
  (GDBusArgInfo **) fdpassing_interface__no_annotation_method_out_args,
  NULL,  /* no annotations */
};

const GDBusArgInfo fdpassing_interface__no_annotation_nested_method_in_args__files_arg =
{
  -1,  /* ref count */
  (gchar *) "files",
  (gchar *) "a{sh}",
  NULL,  /* no annotations */
};

const GDBusArgInfo * const fdpassing_interface__no_annotation_nested_method_in_args[] =
{
  &fdpassing_interface__no_annotation_nested_method_in_args__files_arg,
  NULL,
};

const GDBusMethodInfo fdpassing_interface__no_annotation_nested_method =
{
  -1,  /* ref count */
  (gchar *) "NoAnnotationNested",
  (GDBusArgInfo **) fdpassing_interface__no_annotation_nested_method_in_args,
  NULL,  /* no out args */
  NULL,  /* no annotations */
};

const GDBusMethodInfo * const fdpassing_interface_methods[] =
{
  &fdpassing_interface__hello_fd_method,
  &fdpassing_interface__no_annotation_method,
  &fdpassing_interface__no_annotation_nested_method,
  NULL,
};

const GDBusInterfaceInfo fdpassing_interface =
{
  -1,  /* ref count */
  (gchar *) "FDPassing",
  (GDBusMethodInfo **) fdpassing_interface_methods,
  NULL,  /* no signals */
NULL,  /* no properties */
  NULL,  /* no annotations */
};

/* ------------------------------------------------------------------------ */
/* Definitions for Naming */

const GDBusPropertyInfo naming_interface__type__property =
{
  -1,  /* ref count */
  (gchar *) "Type",
  (gchar *) "i",
  G_DBUS_PROPERTY_INFO_FLAGS_READABLE | G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE,
  NULL,  /* no annotations */
};

const GDBusPropertyInfo * const naming_interface_properties[] =
{
  &naming_interface__type__property,
  NULL,
};

const GDBusInterfaceInfo naming_interface =
{
  -1,  /* ref count */
  (gchar *) "Naming",
  NULL,  /* no methods */
  NULL,  /* no signals */
  (GDBusPropertyInfo **) naming_interface_properties,
  NULL,  /* no annotations */
};

