/*
 * This file is generated by gdbus-codegen, do not modify it.
 *
 * The license of this code is the same as for the D-Bus interface description
 * it was derived from. Note that it links to GLib, so must comply with the
 * LGPL linking clauses.
 */

#ifndef __GDBUS_TEST_CODEGEN_GENERATED_INTERFACE_INFO_H__
#define __GDBUS_TEST_CODEGEN_GENERATED_INTERFACE_INFO_H__

#include <gio/gio.h>

G_BEGIN_DECLS

extern  const GDBusInterfaceInfo org_project_bar_interface;
extern  const GDBusInterfaceInfo org_project_bar_frobnicator_interface;
extern  const GDBusInterfaceInfo org_project_baz_interface;
extern  const GDBusInterfaceInfo com_acme_coyote_interface;
extern  const GDBusInterfaceInfo rocket123_interface;
extern  const GDBusInterfaceInfo org_project_bat_interface;
extern  const GDBusInterfaceInfo org_project_authorize_interface;
extern  const GDBusInterfaceInfo org_project_method_threads_interface;
extern  const GDBusInterfaceInfo org_project_inline_docs_interface;
extern  const GDBusInterfaceInfo changing_interface_v1_interface;
extern  const GDBusInterfaceInfo changing_interface_v2_interface;
extern  const GDBusInterfaceInfo changing_interface_v10_interface;
extern  const GDBusInterfaceInfo test_ugly_case_interface_interface;
extern  const GDBusInterfaceInfo oldie_interface_interface;
extern  const GDBusInterfaceInfo unknown_xml_tags_interface;
extern  const GDBusInterfaceInfo fdpassing_interface;
extern  const GDBusInterfaceInfo naming_interface;

G_END_DECLS

#endif /* __GDBUS_TEST_CODEGEN_GENERATED_INTERFACE_INFO_H__ */
